{% extends "inc/base.j2" %}
{% block content %}
  <h3>update state value / {{ key }}</h3>

  <form method="post">
    <textarea name="value" rows="10" cols="30">{{ value }}</textarea>
    <input type="submit" value="update">
  </form>



{% endblock %}
