@charset "UTF-8";

.flash-error {
    background-color: #f8d7da;
    color: #721c24;
    padding: 10px;
    margin: 10px 0;
    border: 1px solid #f5c6cb;
    border-radius: 5px;
}

.flash-message {
    background-color: #d4edda;
    color: #155724;
    padding: 10px;
    margin: 10px 0;
    border: 1px solid #c3e6cb;
    border-radius: 5px;
}

.sortable thead th:not(.no-sort) {
    cursor: pointer;
}

.sortable thead th:not(.no-sort)::after, .sortable thead th:not(.no-sort)::before {
    transition: color 0.1s ease-in-out;
    font-size: 1.2em;
    color: transparent;
}

.sortable thead th:not(.no-sort)::after {
    margin-left: 3px;
    content: "▸";
}

.sortable thead th:not(.no-sort):hover::after {
    color: inherit;
}

.sortable thead th:not(.no-sort)[aria-sort=descending]::after {
    color: inherit;
    content: "▾";
}

.sortable thead th:not(.no-sort)[aria-sort=ascending]::after {
    color: inherit;
    content: "▴";
}

.sortable thead th:not(.no-sort).indicator-left::after {
    content: "";
}

.sortable thead th:not(.no-sort).indicator-left::before {
    margin-right: 3px;
    content: "▸";
}

.sortable thead th:not(.no-sort).indicator-left:hover::before {
    color: inherit;
}

.sortable thead th:not(.no-sort).indicator-left[aria-sort=descending]::before {
    color: inherit;
    content: "▾";
}

.sortable thead th:not(.no-sort).indicator-left[aria-sort=ascending]::before {
    color: inherit;
    content: "▴";
}